root

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

const (
	Name = "gh-secrets-sync"

	// FlagConfig is the name of the global --config flag.
	FlagConfig = "config"
)

Variables

This section is empty.

Functions

func New

func New(opts ...Option) *cli.Command

New returns the root *cli.Command with the supplied options applied.

Types

type Option

type Option func(*options)

Option is a functional option for configuring the root command.

func WithCommand

func WithCommand(cmd *cli.Command) Option

WithCommand appends a single sub-command to the root command. Call it multiple times to register multiple sub-commands.

func WithOnInit

func WithOnInit(fn cli.BeforeFunc) Option

WithOnInit sets the Before hook called before every command invocation.

func WithVersion

func WithVersion(v string) Option

WithVersion sets the version string shown by --version.

Jump to